:orphan:

🌷️ Thank you for your interest in supporting Cython! 🌷️
=========================================================

Managing, maintaining and advancing a project as large as Cython takes
**a lot of time and dedication**.

**Your support can make a difference**
for a great tool that helps you every day!

Please consider signing a subscription for continuous project support via

* `GitHub Sponsors <https://github.com/users/scoder/sponsorship>`_
* `Tidelift <https://tidelift.com/subscription/pkg/pypi-cython>`_
* `PayPal <https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=HLS9JEYD4ETB6&source=url>`_

or donating via

* `PayPal <https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=HLS9JEYD4ETB6&source=url>`_

Note that PayPal takes 5 - 15% fees for small non-EUR payments,
which is money that *you pay without helping us*.
Consider signing up for a GitHub Sponsors subscription instead,
which is currently free of additional charges.

Also note that we are not accepting donations in crypto currencies.
Much of the development for Cython is done in a carbon-neutral way
or with compensated and very low emissions.
Crypto currencies do not fit into this ambition.


Legal Notice for Donations
--------------------------

Any donation that you make to the Cython project is voluntary and
is not a fee for any services, goods, or advantages.  By making
a donation to the Cython project, you acknowledge that we have the
right to use the money you donate in any lawful way and for any
lawful purpose we see fit and we are not obligated to disclose
the way and purpose to any party unless required by applicable
law.  Although Cython is free software, to the best of our knowledge
the Cython project does not have any tax exempt status.  The Cython
project is neither a registered non-profit corporation nor a
registered charity in any country.  Your donation may or may not
be tax-deductible; please consult your tax advisor in this matter.
We will not publish or disclose your name and/or e-mail address
without your consent, unless required by applicable law.  Your
donation is non-refundable.
